<?php
/**
 * Default theme options.
 *
 * @package Super Business
 */

if ( ! function_exists( 'super_business_get_default_theme_options' ) ) :

	/**
	 * Get default theme options.
	 *
	 * @since 1.0.0
	 *
	 * @return array Default theme options.
	 */
function super_business_get_default_theme_options() {

	$defaults = array();

    // Homepage Options
	$defaults['enable_frontpage_content'] 			= true;

	// Featured Slider Section	
	$defaults['enable_featured_slider_section']		= false;
	$defaults['number_of_featured_slider_items']	= 3;

	// Call to action Section	
	$defaults['enable_call_to_action_section']	   	= false;
	$defaults['call_to_action_title']	   	 		= esc_html__( 'Your Project is in the Right Hands.', 'super-business' );
	$defaults['call_to_action_button_label']	   	= esc_html__( 'Contact Us', 'super-business' );
	$defaults['call_to_action_button_url']	   	 	= '#';

	// About Us Section	
	$defaults['enable_about_us_section']			= false;
	$defaults['about_us_subtitle']					= esc_html__( 'About Us', 'super-business' );
	$defaults['about_us_title']						= esc_html__( 'Professional business solutions for your company', 'super-business' );

	// Choose Us Section	
	$defaults['enable_choose_us_section']			= false;
	$defaults['choose_us_section_subtitle']			= esc_html__( 'Choose Us', 'super-business' );
	$defaults['choose_us_section_title']			= esc_html__( 'Why We Are Best', 'super-business' );
	$defaults['number_of_choose_us_items']			= 2;

	// Latest Posts Section
	$defaults['enable_blog_section']				= false;
	$defaults['blog_section_subtitle']				= esc_html__( 'Articles', 'super-business' );
	$defaults['blog_section_title']					= esc_html__( 'Latest News', 'super-business' );
	$defaults['blog_category']	   					= 0; 
	$defaults['blog_number']						= 3;

	//General Section
	$defaults['your_latest_posts_title']			= esc_html__('Blog','super-business');
	$defaults['excerpt_length']						= 15;
	$defaults['layout_options_blog']				= 'no-sidebar';
	$defaults['layout_options_archive']				= 'no-sidebar';
	$defaults['layout_options_page']				= 'no-sidebar';	
	$defaults['layout_options_single']				= 'right-sidebar';	

	//Footer section 		
	$defaults['copyright_text']					= esc_html__( 'Copyright &copy; All rights reserved.', 'super-business' );

	// Pass through filter.
	$defaults = apply_filters( 'super_business_filter_default_theme_options', $defaults );
	return $defaults;
}

endif;

/**
*  Get theme options
*/
if ( ! function_exists( 'super_business_get_option' ) ) :

	/**
	 * Get theme option
	 *
	 * @since 1.0.0
	 *
	 * @param string $key Option key.
	 * @return mixed Option value.
	 */
	function super_business_get_option( $key ) {

		$default_options = super_business_get_default_theme_options();
		if ( empty( $key ) ) {
			return;
		}

		$theme_options = (array)get_theme_mod( 'theme_options' );
		$theme_options = wp_parse_args( $theme_options, $default_options );

		$value = null;

		if ( isset( $theme_options[ $key ] ) ) {
			$value = $theme_options[ $key ];
		}

		return $value;

	}

endif;